import win32com.client as wincl

def speak(str):
    from win32com.client import Dispatch
    n = 1
    speaker_number = n
    speak = wincl.Dispatch("SAPI.SpVoice")
    vcs = speak.GetVoices()
    SVSFlag = 11
    speak.SetVoice(vcs.Item(speaker_number))
    print(f"AI : {str}")
    speak.Speak(str)



from setuptools import setup

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="Bak-Bak",
    version="0.2",
    description="A Python library for speech synthesis using SAPI.SpVoice",
    long_description=long_description,
    long_description_content_type="text/markdown",
    py_modules=["bakbak"],
    install_requires=["pypiwin32"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
